==> seeds_widgets-2.0.6.zip: seeds_widgets/src/Plugin/Field/FieldFormatter/GridFormatter.php <==
<?php

namespace Drupal\seeds_widgets\Plugin\Field\FieldFormatter;

use Drupal\Core\Entity\ContentEntityInterface;
use Drupal\Core\Field\FieldDefinitionInterface;
use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Field\Plugin\Field\FieldFormatter\EntityReferenceFormatterBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\seeds_widgets\SeedsWidgetsManager;
use Drupal\seeds_widgets\SeedsWidgetTypeInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Plugin implementation of the 'grid' formatter.
 *
 * @FieldFormatter(
 *   id = "seeds_widgets_grid",
 *   label = @Translation("Seeds Widgets Grid"),
 *   field_types = {
 *     "entity_reference_revisions"
 *   }
 * )
 */
class GridFormatter extends EntityReferenceFormatterBase implements ContainerFactoryPluginInterface, SeedsWidgetTypeInterface {

  /**
   * The Seeds Widgets Manager.
   *
   * @var \Drupal\seeds_widgets\SeedsWidgetsManager
   */
  protected $seedsWidgetsManager;

  /**
   * Constructs a GridFormatter object.
   *
   * @param string $plugin_id
   *   The plugin_id for the formatter.
   * @param mixed $plugin_definition
   *   The plugin implementation definition.
   * @param \Drupal\Core\Field\FieldDefinitionInterface $field_definition
   *   The definition of the field to which the formatter is associated.
   * @param array $settings
   *   The formatter settings.
   * @param string $label
   *   The formatter label display setting.
   * @param string $view_mode
   *   The view mode.
   * @param array $third_party_settings
   *   Any third party settings.
   * @param \Drupal\seeds_widgets\SeedsWidgetsManager $seeds_widgets_manager
   *   The Seeds Widgets Manager.
   */
  public function __construct($plugin_id, $plugin_definition, FieldDefinitionInterface $field_definition, array $settings, $label, $view_mode, array $third_party_settings, SeedsWidgetsManager $seeds_widgets_manager) {
    parent::__construct($plugin_id, $plugin_definition, $field_definition, $settings, $label, $view_mode, $third_party_settings);
    $this->seedsWidgetsManager = $seeds_widgets_manager;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $plugin_id,
      $plugin_definition,
      $configuration['field_definition'],
      $configuration['settings'],
      $configuration['label'],
      $configuration['view_mode'],
      $configuration['third_party_settings'],
      $container->get('seeds_widgets.manager')
    );
  }

  /**
   * {@inheritdoc}
   */
  public static function defaultSettings() {
    return [
      'grid_desktop' => 'col-lg-4',
      'grid_tablet' => 'col-md-6',
      'grid_mobile' => 'col-12',
    ] + parent::defaultSettings();
  }

  /**
   * {@inheritdoc}
   */
  public function settingsForm(array $form, FormStateInterface $form_state) {
    $form = parent::settingsForm($form, $form_state);
    $settings = $this->getSettings();

    $desktop_options = [
      'col-lg-12' => $this->t('1 item per row'),
      'col-lg-6' => $this->t('2 items per row'),
      'col-lg-4' => $this->t('3 items per row'),
      'col-lg-3' => $this->t('4 items per row'),
      'col-lg-2' => $this->t('6 items per row'),
    ];

    $tablet_options = [
      'col-md-12' => $this->t('1 item per row'),
      'col-md-6' => $this->t('2 items per row'),
      'col-md-4' => $this->t('3 items per row'),
      'col-md-3' => $this->t('4 items per row'),
    ];

    $mobile_options = [
      'col-12' => $this->t('1 item per row'),
      'col-6' => $this->t('2 items per row'),
      'col-4' => $this->t('3 items per row'),
    ];

    $form['grid_desktop'] = [
      '#type' => 'radios',
      '#title' => $this->t('Desktop Layout'),
      '#options' => $desktop_options,
      '#default_value' => $settings['grid_desktop'],
      '#description' => $this->t('Choose how many items you want to display per row on desktop screens.'),
    ];

    $form['grid_tablet'] = [
      '#type' => 'radios',
      '#title' => $this->t('Tablet Layout'),
      '#options' => $tablet_options,
      '#default_value' => $settings['grid_tablet'],
      '#description' => $this->t('Choose how many items you want to display per row on tablet screens.'),
    ];

    $form['grid_mobile'] = [
      '#type' => 'radios',
      '#title' => $this->t('Mobile Layout'),
      '#options' => $mobile_options,
      '#default_value' => $settings['grid_mobile'],
      '#description' => $this->t('Choose how many items you want to display per row on mobile screens.'),
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function settingsSummary() {
    $summary = parent::settingsSummary();
    $settings = $this->getSettings();

    $summary[] = $this->t('Grid classes: @desktop, @tablet, @mobile', [
      '@desktop' => $settings['grid_desktop'],
      '@tablet' => $settings['grid_tablet'],
      '@mobile' => $settings['grid_mobile'],
    ]);

    return $summary;
  }

  /**
   * {@inheritdoc}
   */
  public function viewElements(FieldItemListInterface $items, $langcode) {
    $elements = [];

    if ($items->isEmpty()) {
      return $elements;
    }

    $settings = $this->getSettings();
    $entities = $this->getEntitiesToView($items, $langcode);
    $processed_items = [];

    foreach ($entities as $delta => $entity) {
      if (!$entity) {
        continue;
      }

      $view_builder = \Drupal::entityTypeManager()->getViewBuilder($entity->getEntityTypeId());

      // Check if the paragraph has a custom view mode field and use that.
      $view_mode = $this->viewMode;
      if ($entity instanceof ContentEntityInterface &&
          $entity->hasField('field_seeds_widget_view_mode') &&
          !$entity->get('field_seeds_widget_view_mode')->isEmpty()) {
        $custom_view_mode = $entity->get('field_seeds_widget_view_mode')->target_id;
        if ($custom_view_mode) {
          $view_mode = str_replace("paragraph.", "", $custom_view_mode);
        }
      }

      $processed_items[$delta] = [
        'content' => $view_builder->view($entity, $view_mode, $entity->language()->getId()),
        '#paragraph' => $entity,
      ];
    }

    // Build the base render array with widget-specific theme.
    $elements[0] = [
      '#theme' => 'seeds_widgets_paragraph_formatter__grid',
      '#items' => $processed_items,
      '#widget_type' => 'grid',
      '#settings' => $settings,
    ];

    return $elements;
  }

}

==> seeds_widgets-2.5.1.zip: seeds_widgets/src/Plugin/Field/FieldFormatter/GridFormatter.php <==
<?php

namespace Drupal\seeds_widgets\Plugin\Field\FieldFormatter;

use Drupal\Core\Entity\ContentEntityInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Field\FieldDefinitionInterface;
use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Field\Plugin\Field\FieldFormatter\EntityReferenceFormatterBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\seeds_widgets\SeedsWidgetsManager;
use Drupal\seeds_widgets\SeedsWidgetTypeInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Plugin implementation of the 'grid' formatter.
 *
 * @FieldFormatter(
 *   id = "seeds_widgets_grid",
 *   label = @Translation("Seeds Widgets Grid"),
 *   field_types = {
 *     "entity_reference_revisions"
 *   }
 * )
 */
class GridFormatter extends EntityReferenceFormatterBase implements ContainerFactoryPluginInterface, SeedsWidgetTypeInterface {

  /**
   * The Seeds Widgets Manager.
   *
   * @var \Drupal\seeds_widgets\SeedsWidgetsManager
   */
  protected $seedsWidgetsManager;

  /**
   * The entity type manager.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected $entityTypeManager;

  /**
   * Constructs a GridFormatter object.
   *
   * @param string $plugin_id
   *   The plugin_id for the formatter.
   * @param mixed $plugin_definition
   *   The plugin implementation definition.
   * @param \Drupal\Core\Field\FieldDefinitionInterface $field_definition
   *   The definition of the field to which the formatter is associated.
   * @param array $settings
   *   The formatter settings.
   * @param string $label
   *   The formatter label display setting.
   * @param string $view_mode
   *   The view mode.
   * @param array $third_party_settings
   *   Any third party settings.
   * @param \Drupal\seeds_widgets\SeedsWidgetsManager $seeds_widgets_manager
   *   The Seeds Widgets Manager.
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entity_type_manager
   *   The entity type manager.
   */
  public function __construct($plugin_id, $plugin_definition, FieldDefinitionInterface $field_definition, array $settings, $label, $view_mode, array $third_party_settings, SeedsWidgetsManager $seeds_widgets_manager, EntityTypeManagerInterface $entity_type_manager) {
    parent::__construct($plugin_id, $plugin_definition, $field_definition, $settings, $label, $view_mode, $third_party_settings);
    $this->seedsWidgetsManager = $seeds_widgets_manager;
    $this->entityTypeManager = $entity_type_manager;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $plugin_id,
      $plugin_definition,
      $configuration['field_definition'],
      $configuration['settings'],
      $configuration['label'],
      $configuration['view_mode'],
      $configuration['third_party_settings'],
      $container->get('seeds_widgets.manager'),
      $container->get('entity_type.manager')
    );
  }

  /**
   * {@inheritdoc}
   */
  public static function defaultSettings() {
    return [
      'grid_desktop' => 'col-lg-4',
      'grid_tablet' => 'col-md-6',
      'grid_mobile' => 'col-12',
    ] + parent::defaultSettings();
  }

  /**
   * {@inheritdoc}
   */
  public function settingsForm(array $form, FormStateInterface $form_state) {
    $form = parent::settingsForm($form, $form_state);
    $settings = $this->getSettings();

    $desktop_options = [
      'col-lg-12' => $this->t('1 item per row'),
      'col-lg-6' => $this->t('2 items per row'),
      'col-lg-4' => $this->t('3 items per row'),
      'col-lg-3' => $this->t('4 items per row'),
      'col-lg-2' => $this->t('6 items per row'),
    ];

    $tablet_options = [
      'col-md-12' => $this->t('1 item per row'),
      'col-md-6' => $this->t('2 items per row'),
      'col-md-4' => $this->t('3 items per row'),
      'col-md-3' => $this->t('4 items per row'),
    ];

    $mobile_options = [
      'col-12' => $this->t('1 item per row'),
      'col-6' => $this->t('2 items per row'),
      'col-4' => $this->t('3 items per row'),
    ];

    $form['grid_desktop'] = [
      '#type' => 'radios',
      '#title' => $this->t('Desktop Layout'),
      '#options' => $desktop_options,
      '#default_value' => $settings['grid_desktop'],
      '#description' => $this->t('Choose how many items you want to display per row on desktop screens.'),
    ];

    $form['grid_tablet'] = [
      '#type' => 'radios',
      '#title' => $this->t('Tablet Layout'),
      '#options' => $tablet_options,
      '#default_value' => $settings['grid_tablet'],
      '#description' => $this->t('Choose how many items you want to display per row on tablet screens.'),
    ];

    $form['grid_mobile'] = [
      '#type' => 'radios',
      '#title' => $this->t('Mobile Layout'),
      '#options' => $mobile_options,
      '#default_value' => $settings['grid_mobile'],
      '#description' => $this->t('Choose how many items you want to display per row on mobile screens.'),
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function settingsSummary() {
    $summary = parent::settingsSummary();
    $settings = $this->getSettings();

    $summary[] = $this->t('Grid classes: @desktop, @tablet, @mobile', [
      '@desktop' => $settings['grid_desktop'],
      '@tablet' => $settings['grid_tablet'],
      '@mobile' => $settings['grid_mobile'],
    ]);

    return $summary;
  }

  /**
   * {@inheritdoc}
   */
  public function viewElements(FieldItemListInterface $items, $langcode) {
    $elements = [];

    if ($items->isEmpty()) {
      return $elements;
    }

    $settings = $this->getSettings();
    $entities = $this->getEntitiesToView($items, $langcode);
    $processed_items = [];

    foreach ($entities as $delta => $entity) {
      if (!$entity) {
        continue;
      }

      $view_builder = $this->entityTypeManager->getViewBuilder($entity->getEntityTypeId());

      // Check if the paragraph has a custom view mode field and use that.
      $view_mode = $this->viewMode;
      if ($entity instanceof ContentEntityInterface &&
        $entity->hasField('field_seeds_widget_view_mode') &&
        !$entity->get('field_seeds_widget_view_mode')->isEmpty()) {
        $custom_view_mode = $entity->get('field_seeds_widget_view_mode')->target_id;
        if ($custom_view_mode) {
          $view_mode = str_replace("paragraph.", "", $custom_view_mode);
        }
      }

      $processed_items[$delta] = [
        'content' => $view_builder->view($entity, $view_mode, $entity->language()->getId()),
        '#paragraph' => $entity,
      ];
    }

    // Build the base render array with widget-specific theme.
    $elements[0] = [
      '#theme' => 'seeds_widgets_paragraph_formatter__grid',
      '#items' => $processed_items,
      '#widget_type' => 'grid',
      '#settings' => $settings,
    ];

    return $elements;
  }

}
